==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/media/kotlin/inputs/StreamingLocatorContentKeyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.media.kotlin.inputs

import com.pulumi.azurenative.media.inputs.StreamingLocatorContentKeyArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Class for content key in Streaming Locator
 * @property id ID of Content Key
 * @property labelReferenceInStreamingPolicy Label of Content Key as specified in the Streaming Policy
 * @property value Value of Content Key
 */
public data class StreamingLocatorContentKeyArgs(
    public val id: Output<String>,
    public val labelReferenceInStreamingPolicy: Output<String>? = null,
    public val `value`: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.media.inputs.StreamingLocatorContentKeyArgs> {
    override fun toJava(): com.pulumi.azurenative.media.inputs.StreamingLocatorContentKeyArgs =
        com.pulumi.azurenative.media.inputs.StreamingLocatorContentKeyArgs.builder()
            .id(id.applyValue({ args0 -> args0 }))
            .labelReferenceInStreamingPolicy(labelReferenceInStreamingPolicy?.applyValue({ args0 -> args0 }))
            .`value`(`value`?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [StreamingLocatorContentKeyArgs].
 */
@PulumiTagMarker
public class StreamingLocatorContentKeyArgsBuilder internal constructor() {
    private var id: Output<String>? = null

    private var labelReferenceInStreamingPolicy: Output<String>? = null

    private var `value`: Output<String>? = null

    /**
     * @param value ID of Content Key
     */
    @JvmName("pfvgeyyhkryvtkxa")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value Label of Content Key as specified in the Streaming Policy
     */
    @JvmName("stqkarhkglsvagev")
    public suspend fun labelReferenceInStreamingPolicy(`value`: Output<String>) {
        this.labelReferenceInStreamingPolicy = value
    }

    /**
     * @param value Value of Content Key
     */
    @JvmName("wmmqurwpkcjdsqxn")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value ID of Content Key
     */
    @JvmName("epjmsdygaksppgtq")
    public suspend fun id(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value Label of Content Key as specified in the Streaming Policy
     */
    @JvmName("apbqirtfdudxxdyw")
    public suspend fun labelReferenceInStreamingPolicy(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.labelReferenceInStreamingPolicy = mapped
    }

    /**
     * @param value Value of Content Key
     */
    @JvmName("tyrvnlrphvpagjom")
    public suspend fun `value`(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): StreamingLocatorContentKeyArgs = StreamingLocatorContentKeyArgs(
        id = id ?: throw PulumiNullFieldException("id"),
        labelReferenceInStreamingPolicy = labelReferenceInStreamingPolicy,
        `value` = `value`,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/media/kotlin/inputs/StreamingLocatorContentKeyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.media.kotlin.inputs

import com.pulumi.azurenative.media.inputs.StreamingLocatorContentKeyArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Class for content key in Streaming Locator
 * @property id ID of Content Key
 * @property labelReferenceInStreamingPolicy Label of Content Key as specified in the Streaming Policy
 * @property value Value of Content Key
 */
public data class StreamingLocatorContentKeyArgs(
    public val id: Output<String>,
    public val labelReferenceInStreamingPolicy: Output<String>? = null,
    public val `value`: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.media.inputs.StreamingLocatorContentKeyArgs> {
    override fun toJava(): com.pulumi.azurenative.media.inputs.StreamingLocatorContentKeyArgs =
        com.pulumi.azurenative.media.inputs.StreamingLocatorContentKeyArgs.builder()
            .id(id.applyValue({ args0 -> args0 }))
            .labelReferenceInStreamingPolicy(labelReferenceInStreamingPolicy?.applyValue({ args0 -> args0 }))
            .`value`(`value`?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [StreamingLocatorContentKeyArgs].
 */
@PulumiTagMarker
public class StreamingLocatorContentKeyArgsBuilder internal constructor() {
    private var id: Output<String>? = null

    private var labelReferenceInStreamingPolicy: Output<String>? = null

    private var `value`: Output<String>? = null

    /**
     * @param value ID of Content Key
     */
    @JvmName("fxbbyfhogvnddqtt")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value Label of Content Key as specified in the Streaming Policy
     */
    @JvmName("tvbnkewlavxtptev")
    public suspend fun labelReferenceInStreamingPolicy(`value`: Output<String>) {
        this.labelReferenceInStreamingPolicy = value
    }

    /**
     * @param value Value of Content Key
     */
    @JvmName("dwgsnmwiipbydpol")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value ID of Content Key
     */
    @JvmName("uinrrgtysvsmvhjy")
    public suspend fun id(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value Label of Content Key as specified in the Streaming Policy
     */
    @JvmName("upwpxpasnxtetkbc")
    public suspend fun labelReferenceInStreamingPolicy(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.labelReferenceInStreamingPolicy = mapped
    }

    /**
     * @param value Value of Content Key
     */
    @JvmName("wnrlipjjpbhpcafs")
    public suspend fun `value`(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): StreamingLocatorContentKeyArgs = StreamingLocatorContentKeyArgs(
        id = id ?: throw PulumiNullFieldException("id"),
        labelReferenceInStreamingPolicy = labelReferenceInStreamingPolicy,
        `value` = `value`,
    )
}
